import { Switch, Route, useLocation } from "wouter";
import { lazy, Suspense } from "react";
import { queryClient } from "./lib/queryClient";
import { QueryClientProvider } from "@tanstack/react-query";
import { Toaster } from "@/components/ui/toaster";
import { TooltipProvider } from "@/components/ui/tooltip";
import { AuthProvider, useAuth } from "@/hooks/use-auth";
import Navigation from "@/components/navigation";

// Lazy load heavy components
const Landing = lazy(() => import("@/pages/landing"));
const Home = lazy(() => import("@/pages/home"));
const Editor = lazy(() => import("@/pages/editor"));
const Subscribe = lazy(() => import("@/pages/subscribe"));
const Dashboard = lazy(() => import("@/pages/dashboard"));
const AiDetector = lazy(() => import("@/pages/ai-detector"));
const Pricing = lazy(() => import("@/pages/pricing"));
const Blogs = lazy(() => import("@/pages/blogs"));
const BlogArticle = lazy(() => import("@/pages/blog-article"));
const Profile = lazy(() => import("@/pages/profile"));
const WriterDashboard = lazy(() => import("@/pages/writer-dashboard"));
const AdminDashboard = lazy(() => import("@/pages/admin-dashboard"));
const AdminUsers = lazy(() => import("@/pages/admin-users"));
const AdminLogin = lazy(() => import("@/pages/admin-login"));
const DatabaseViewer = lazy(() => import("@/pages/database-viewer"));
const ManualRewrite = lazy(() => import("@/pages/manual-rewrite"));
const Payment = lazy(() => import("@/pages/payment"));
const PaymentSuccess = lazy(() => import("@/pages/payment-success"));
const PaymentHistory = lazy(() => import("@/pages/payment-history"));
const ActivateAccount = lazy(() => import("@/pages/activate-account"));
const SignupPage = lazy(() => import("@/pages/signup"));
const LoginPage = lazy(() => import("@/pages/login"));
const ResetPasswordPage = lazy(() => import("@/pages/reset-password"));
const ForgotPasswordPage = lazy(() => import("@/pages/forgot-password"));
const NotFound = lazy(() => import("@/pages/not-found"));

// Optimized loading component with skeleton
const PageLoader = () => (
  <div className="min-h-screen flex items-center justify-center bg-gradient-to-br from-blue-50 to-purple-50">
    <div className="text-center">
      <div className="animate-spin w-8 h-8 border-4 border-primary border-t-transparent rounded-full mx-auto mb-4"></div>
      <p className="text-gray-600 text-sm">Loading Humanize AI...</p>
    </div>
  </div>
);

function Router() {
  const { user, isLoading } = useAuth();
  const [location] = useLocation();
  const isAuthenticated = !!user;

  // Pages that have their own navigation or should show authenticated navigation
  const publicPages = ['/signup', '/login', '/reset-password', '/forgot-password'];
  const showGlobalNav = !publicPages.includes(location) && isAuthenticated;

  // Show loading state while authentication is being checked
  if (isLoading) {
    return (
      <div className="min-h-screen flex items-center justify-center">
        <div className="animate-spin w-8 h-8 border-4 border-primary border-t-transparent rounded-full"></div>
      </div>
    );
  }

  return (
    <div>
      {/* Navigation - Show only for pages that need it */}
      {showGlobalNav && <Navigation />}

      <Suspense fallback={<PageLoader />}>
        <Switch>
          {/* Public pages - accessible without authentication */}
          <Route path="/" component={isAuthenticated ? Home : Landing} />
          <Route path="/signup" component={SignupPage} />
          <Route path="/login" component={LoginPage} />
          <Route path="/forgot-password" component={ForgotPasswordPage} />
          <Route path="/reset-password" component={ResetPasswordPage} />
          <Route path="/ai-detector" component={AiDetector} />
          <Route path="/pricing" component={Pricing} />
          <Route path="/blogs" component={Blogs} />
          <Route path="/blogs/:slug" component={BlogArticle} />
          <Route path="/manual-rewrite" component={ManualRewrite} />
          <Route path="/payment" component={Payment} />
          <Route path="/payment-success" component={PaymentSuccess} />
          <Route path="/payment-history" component={PaymentHistory} />
          <Route path="/activate-account" component={ActivateAccount} />
          <Route path="/admin-login" component={AdminLogin} />
          <Route path="/database" component={DatabaseViewer} />

          {/* Protected pages - require authentication */}
          {isAuthenticated && (
            <>
              <Route path="/editor" component={Editor} />
              <Route path="/subscribe" component={Subscribe} />
              <Route path="/dashboard" component={Dashboard} />
              <Route path="/profile" component={Profile} />
              <Route path="/writer-dashboard" component={WriterDashboard} />
              <Route path="/admin-dashboard" component={AdminDashboard} />
              <Route path="/admin-users" component={AdminUsers} />
            </>
          )}

          <Route component={NotFound} />
        </Switch>
      </Suspense>
    </div>
  );
}

function App() {
  return (
    <QueryClientProvider client={queryClient}>
      <AuthProvider>
        <TooltipProvider>
          <Toaster />
          <Router />
        </TooltipProvider>
      </AuthProvider>
    </QueryClientProvider>
  );
}

export default App;